"use strict";
const RequestQueue = require("@poccomaxa/request-queue");
const qs = require("querystring");
const queue = new RequestQueue({}, 1, false);

function APICall(method, args) {
    async function req(cb) {
        let res = await queue.post("https://faucethub.io/api/v1/" + method, qs.stringify(args));
        let resObj;
        try {
            resObj = JSON.parse(res.text);
        } catch (e) {
            resObj = res.text;
        }
        cb instanceof Function && cb(resObj);
    }

    req();
}

class FaucethubAPI {
    constructor(api_key, currency) {
        this.key = api_key;
        this._cur = currency;
    }

    getBalance(cb) {
        APICall("getbalance", {
            api_key: this.key,
            currency: this._cur
        }, cb);
    }

    checkAddress(address, cb) {
        APICall("checkaddress", {
            api_key: this.key,
            address: address,
            currency: this._cur
        }, cb);
    }

    send(address, amount, cb) {
        APICall("send", {
            api_key: this.key,
            amount: amount,
            to: address,
            currency: this._cur
        }, cb);
    }

    payouts(count, cb) {
        APICall("payouts", {
            api_key: this.key,
            count: count,
            currency: this._cur
        }, cb);
    }
}

module.exports = FaucethubAPI;